@@ -1,7 +1,8 @@
 import attr
 import cattr
+from datetime import date
 from typing import Any, Dict, List, Optional
-from sdgs_tools.dashboard.enums import (
+from .enums import (
     Agama,
     AksesInternet,
     JenisKelamin,
@@ -32,7 +33,7 @@ class DataIndividu:
     nama: str
     jenis_kelamin: JenisKelamin
     tempat_lahir: str
-    tanggal_lahir: str
+    tanggal_lahir: date
     usia: str
     status_pernikahan: StatusPernikahan
     usia_menikah: str
