@@ -4,6 +4,7 @@ from .auth import BaseAuth
 from .import_individu import DataIndividu
 
 
+
 class Sdgs(BaseAuth):
     def __init__(
         self,
@@ -23,8 +24,9 @@ class Sdgs(BaseAuth):
             "surveyIndividu/validateNik",
             str,
             json=json_data,
+            ignore=True,
         )
-        return bool(res)
+        return bool(res) or res.message == "NIK Sudah Ada"
 
     def save_individu(self, individu: DataIndividu, rt: str, rw: str):
         data_individu = individu.make_data(desa=self.token.wilayah, rt=rt, rw=rw)
